#include "WProgressBar.h"

#include <Wt/WText>
#include <Wt/WContainerWidget>
#include <boost/format.hpp>

using namespace Wt;

namespace Wt {

//! \brief Create the progress bar
WProgressBar::WProgressBar( WContainerWidget * parent )
   : WCompositeWidget( parent ), value_(0), min_(0), max_(100)
{
   WContainerWidget * barimpl;
   setImplementation( barimpl = new WContainerWidget() );
   barimpl->setStyleClass("ProgressBar");
   barimpl->setInline(true);
   bar_ = new WContainerWidget( barimpl );
   text_ = new WText( barimpl );
   draw();
}

//! \brief Retrieves the progress
//!
//! \return value
double WProgressBar::getValue()
{
   return value_;
}

//! \brief Sets the progress to the desired value
//!
//! \param [in] value Progress
void WProgressBar::setValue( double value )
{
   value_ = value;
   draw();
}

//! \brief Retrieves the minimum
//!
//! \return minimum
double WProgressBar::getMin()
{
   return min_;
}

//! \brief Sets the minimum progress
//!
//! \param [in] value Progress
void WProgressBar::setMin( double value )
{
   min_ = value;
   draw();
}

//! \brief Retrieves the maximum
//!
//! \return maximum
double WProgressBar::getMax()
{
   return max_;
}

//! \brief Sets the maximum progress
//!
//! \param [in] value maximum
void WProgressBar::setMax( double value )
{
   max_ = value;
   draw();
}

//! Increment the value
void WProgressBar::inc()
{
   ++value_;
   draw();
}

//! Decrement the value
void WProgressBar::dec()
{
   --value_;
   draw();
}

void WProgressBar::draw()
{
   double percent = (value_ - min_) * 100 / (max_ - min_);
   bar_->resize( WLength(percent,WLength::Percentage),WLength(100,WLength::Percentage) );
   text_->setText( (boost::format("%1%%%") % percent).str() );
}

}

